Determination of an empirical null distribution of the QTL significance threshold for a MPP QTL analysis using permutation test (Churchill and Doerge, 1994).
mpp_perm(mppData, trait = 1, Q.eff = "cr", N = 1000, q.val = 0.95,
verbose = TRUE, n.cores = 1)An object of class mppData.
Numerical or character indicator to specify which
trait of the mppData object should be used. Default = 1.
Character expression indicating the assumption concerning
the QTL effects: 1) "cr" for cross-specific; 2) "par" for parental; 3) "anc"
for ancestral; 4) "biall" for a bi-allelic. For more details see
mpp_SIM. Default = "cr".
Number of permutations. Default = 1000.
Single numeric value or vector of desired quantiles from
the null distribution. Default = 0.95.
Logical value indicating if progression of the function
should be printed. It will not affect the printing of the other functions
called by mpp_perm(), especially the printing of asreml().
Default = TRUE.
Numeric. Specify here the number of cores you like to
use. Default = 1.
Return:
List with the following object:
Vector of the highest genome-wide -log10(p-values).
Quantile values from the QTL significance threshold null distribution.
Numeric vector of random generated seed values for each
permutation.
Performs N permutations of the trait data and
computes each time a genome-wide QTL profile. For every run, it stores the
highest -log10(p-val). These values can be used to build a null distribution
for the QTL significance threshold. Quantile values can be determined from
the previous distribution. For more details about the different possible
models and their assumptions see mpp_SIM documentation.
Churchill, G. A., & Doerge, R. W. (1994). Empirical threshold values for quantitative trait mapping. Genetics, 138(3), 963-971.
# NOT RUN {
data(mppData)
Perm <- mpp_perm(mppData = mppData, Q.eff = "cr", N = 5)
# }
Run the code above in your browser using DataLab