Build multi-QTL effects (MQE) models in which different QTL effects (cross-specific, parental, ancestral or bi-allelic) can be assumed at different loci.
MQE_proc(pop.name = "MPP_MQE", trait.name = "trait1", mppData = NULL,
trait = 1, Q.eff, threshold = 4, window = 30, backward = TRUE,
alpha.bk = 0.05, plot.MQE = FALSE, n.cores = 1, verbose = TRUE,
output.loc)Character name of the studied population.
Default = "MPP_MQE".
Character name of the studied trait.
Default = "trait1".
An object of class mppData.
Numerical or character indicator to specify which
trait of the mppData object should be used. Default = 1.
Character vector of possible QTL effects the user want to
test. Elements of Q.eff can be "cr", "par", "anc" or "biall".
For details look at mpp_SIM.
Numeric value representing the -log10(p-value)
threshold above which a position can be considered as significant.
Default = 4.
Numeric distance (cM) on the left and the right of a
cofactor position where it is not included in the model. Default = 30.
Logical value. If backward = TRUE,
the function performs
a backward elimination on the list of selected QTLs. Default = TRUE.
Numeric value indicating the significance level for
the backward elimination. Default = 0.05.
Logical value. If plot.MQE = TRUE,
the function will plot the last run of the MQE model determination.
Default = FALSE.
Numeric. Specify here the number of cores you like to
use. Default = 1.
Logical value indicating if the steps of MQE_proc should
be printed. Default = TRUE.
Path where a folder will be created to save the results.
Return:
List containing the following items:
Number of detected QTLs.
Data.frame with QTL positions.
list containing R squared statistics of the QTL effects.
for details see QTL_R2.
List of genetic effects per QTL.
Some output files are also saved at the location specified (output.loc):
A QTL report (QTL_REPORT.txt) with: 1) the number of detected QTLs; 2) the global R squared statistics; 3) for each QTL, position information and estimated QTL genetic effect per cross or parents.
The list of QTLs (QTL.txt).
The QTL R squared statistics (QTL_R2.txt) (for details see
QTL_R2).
General results of the QTL detection process: Number of QTL and global adjusted and non-adjusted R squared statistics. (QTL_genResults.txt).
if plot.MQE = TRUE, a plot of the last QTL detection run profile
(plot_MQE.pdf).
The possible QTL effect that the user wants to allow must be
specified in Q.eff. The procedure is the following:
Forward regression to determine a MQE model with different possible assumptions for the QTL effect at different loci. The function use.
Optional backward elimination (backward = TRUE) on the final
list of detected QTLs.
Estimation of the QTL genetic effects and R squared statistics.
Optional plot (plot.MQE = TRUE) of the last CIM run of the
forward regression using the function.
# NOT RUN {
data(mppData)
# Specify a location where your results will be saved
my.loc <- tempdir()
MQE <- MQE_proc(pop.name = "USNAM", trait.name = "ULA", mppData = mppData,
Q.eff = c("par", "biall"), verbose = FALSE,
output.loc = my.loc)
# }
Run the code above in your browser using DataLab